package com.ruoyi.manage.service.impl;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.manage.domain.ChannelNumber;
import com.ruoyi.manage.mapper.ChannelNumberMapper;
import com.ruoyi.manage.service.IChannelNumberService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import java.util.List;


/**
 * 通道管理Service业务层处理
 * 
 * @author boman
 * @date 2025-05-07
 */
@Service
public class ChannelNumberServiceImpl implements IChannelNumberService
{
    @Autowired
    private ChannelNumberMapper channelNumberMapper;

    /**
     * 查询通道管理
     * 
     * @param channelId 通道管理主键
     * @return 通道管理
     */
    @Override
    public ChannelNumber selectChannelNumberByChannelId(Long channelId)
    {
        return channelNumberMapper.selectChannelNumberByChannelId(channelId);
    }

    /**
     * 查询通道管理列表
     * 
     * @param channelNumber 通道管理
     * @return 通道管理
     */
    @Override
    public List<ChannelNumber> selectChannelNumberList(ChannelNumber channelNumber)
    {
        return channelNumberMapper.selectChannelNumberList(channelNumber);
    }

    /**
     * 新增通道管理
     * 
     * @param channelNumber 通道管理
     * @return 结果
     */
    @Override
    public int insertChannelNumber(ChannelNumber channelNumber)
    {
        channelNumber.setCreateTime(DateUtils.getNowDate());
        return channelNumberMapper.insertChannelNumber(channelNumber);
    }

    /**
     * 修改通道管理
     * 
     * @param channelNumber 通道管理
     * @return 结果
     */
    @Override
    public int updateChannelNumber(ChannelNumber channelNumber)
    {
        channelNumber.setUpdateTime(DateUtils.getNowDate());
        return channelNumberMapper.updateChannelNumber(channelNumber);
    }

    /**
     * 批量删除通道管理
     * 
     * @param channelIds 需要删除的通道管理主键
     * @return 结果
     */
    @Override
    public int deleteChannelNumberByChannelIds(Long[] channelIds)
    {
        return channelNumberMapper.deleteChannelNumberByChannelIds(channelIds);
    }

    /**
     * 删除通道管理信息
     * 
     * @param channelId 通道管理主键
     * @return 结果
     */
    @Override
    public int deleteChannelNumberByChannelId(Long channelId)
    {
        return channelNumberMapper.deleteChannelNumberByChannelId(channelId);
    }
}
